#
# spec file for package lsvpd
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lsvpd
Version:        1.7.11
Release:        3.6.1
Summary:        VPD Hardware Inventory Utilities for Linux
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://github.com/power-ras/lsvpd
Source:         https://github.com/power-ras/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:         lsvpd-sysvpd-Add-UUID-property.patch
Patch2:         lsvpd-nvme-Populate-NVMe-firmware-version.patch
Patch3:         lsvpd-sysfs-Fix-PCI-device-manufacturer-parsing-logic.patch
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  librtas-devel
BuildRequires:  libtool
BuildRequires:  libvpd2-devel
BuildRequires:  sg3_utils-devel
BuildRequires:  zlib-devel
Requires:       /bin/sed
Recommends:     hwdata
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  ppc ppc64 ppc64le

%description
The lsvpd package contains both the lsvpd, lscfg and lsmcode commands.
These commands, along with a boot-time scanning script called
update-device-tree, constitute a simple hardware inventory system. The
lsvpd command provides Vital Product Data (VPD) about hardware
components to higher-level serviceability tools. The lscfg command
provides a more human-readable format of the VPD, as well as some
system-specific information.  lsmcode lists microcode and firmware
levels.

%prep
%setup -q
%autopatch -p1

%build
export CFLAGS="%{optflags} -UPCI_IDS -DPCI_IDS='\"%{_datadir}/pci.ids\"' -UUSB_IDS -DUSB_IDS='\"%{_datadir}/usb.ids\"'"
export CXXFLAGS="%{optflags} -UPCI_IDS -DPCI_IDS='\"%{_datadir}/pci.ids\"' -UUSB_IDS -DUSB_IDS='\"%{_datadir}/usb.ids\"'"
sh bootstrap.sh
%configure
make %{?_smp_mflags}
chmod 644 README* COPYING NEWS

%install
%make_install
mkdir %{buildroot}/sbin
for i in lscfg lsmcode lsvio lsvpd update-lsvpd-db
do
 if test -f %{buildroot}%{_sbindir}/$i
 then
   ln -sfvbn ..%{_sbindir}/$i %{buildroot}/sbin/$i
 fi
done
if [ -e %{_sysconfdir}/udev/rules.d/99-lsvpd.rules ] ; then
	rm %{_sysconfdir}/udev/rules.d/99-lsvpd.rules
fi
if [ -e %{_sysconfdir}/udev/rules.d/99-lsvpd.disabled ] ; then
	rm %{_sysconfdir}/udev/rules.d/99-lsvpd.disabled
fi

%post
if [ -d %{_localstatedir}/lib/lsvpd ] ; then
  rm -rf %{_localstatedir}/lib/lsvpd
fi
%{_sbindir}/vpdupdate
exit 0

%files
%defattr(-,root,root)
%license COPYING
%doc README NEWS
%dir %{_sysconfdir}/lsvpd
%attr (644,root,root) %config %{_sysconfdir}/lsvpd/*
/sbin/*
%attr (755,root,root) %{_sbindir}/*
%{_mandir}/*/*

%changelog
* Tue Jan 26 2021 msuchanek@suse.de
- Fix display of NVME adapter firmware version (bsc#1181336 ltc#190621).
  + lsvpd-nvme-Populate-NVMe-firmware-version.patch
  + lsvpd-sysvpd-Add-UUID-property.patch
  + lsvpd-sysfs-Fix-PCI-device-manufacturer-parsing-logic.patch
* Thu Nov  5 2020 msuchanek@suse.com
- Update to upstream version 1.7.11 (jsc#SLE-12938).
  * lsvpd: Dont byteswap the CD field in Description
  * nvme: Update config file with f1h Logpage version 0002
  * lsvpd: Add version and debug options to man page
  - Drop upstreamed patch bsc1163284-Add_version_and_debug_options_to_man_page.patch
  - Update project URL
* Wed May  6 2020 josef.moellers@suse.com
- Added "Recommends: hwdata" to prevent "usb.ids file not found"
  error message.
  [lsvpd.spec, bsc#1171188]
* Tue Apr 21 2020 josef.moellers@suse.com
- The lsvpd man page and --help are not in sync. The version and
  debug options were missing. This patch adds the two options to the
  man page.
  [bsc#1163284,
  bsc1163284-Add_version_and_debug_options_to_man_page.patch]
* Mon Nov  4 2019 josef.moellers@suse.com
- Upgrade to 1.7.10
  * vpdupdate: Delete vpd.db when program gets aborted
  * Enable NVME f1h log page VPD information parsing
  [jsc#SLE-8327, bsc#1155795]
* Wed Jun 20 2018 jloeser@suse.com
- version update to 1.7.9 (fate#324941, fate#326426)
  - vpdupdate: Remove old archive db
  - Add support to parse OPFR record format
  - lsmcode: Add product version string to firmware information
  - lsmcode: Support firmware info on BMC based Power9 system
- removed patches:
  * lsvpd.bug-1072079_add_host_number.patch
  * lsvpd.bug-1072079_std_io_base_failure_workaround.patch
* Mon Dec 18 2017 jloeser@suse.com
- bug fixes (bsc#1072079)
  - Add host number in device location code to distinguish
    different devices
  - Add workaround for std::ios_base::failure issue
- added patches:
  * lsvpd.bug-1072079_add_host_number.patch
  * lsvpd.bug-1072079_std_io_base_failure_workaround.patch
* Mon Mar 27 2017 jloeser@suse.com
- version update to 1.7.8 (fate#321440, fate#322222)
  - Remove temporary block file creation under /tmp
  - Various bug fixes
* Tue Apr 12 2016 jloeser@suse.com
- version update to 1.7.7 (FATE#319553)
  - for changes see lsvpd-1.7.7/ChangeLog
* Mon Nov  9 2015 p.drouand@gmail.com
- Update to version 1.7.6
  * lsmcode is enhanced to support OpenPower systems
  * Fixed security issues like buffer overflow, memory allocation
    validation
  * Improved error handling
- Remove dependency on fillup and insserv; the package doesn't contain
  any sysvinit nor sysconfig file
- Remove patches; fixed on upstream release
  * lsvpd.no-return-in-nonvoid-function.patch
  * lsvpd.bug-941938_add_powerkvm_guest_detection1.patch
  * lsvpd.bug-941938_add_powerkvm_guest_detection2.patch
* Fri Aug 28 2015 jloeser@suse.com
- support lsvpd on PowerKVM guest (bsc#941938)
- added patches:
  * lsvpd.bug-941938_add_powerkvm_guest_detection1.patch
  * lsvpd.bug-941938_add_powerkvm_guest_detection2.patch
* Mon Apr 20 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
* Thu Sep  4 2014 jloeser@suse.com
- version update to 1.7.5 (BNC#894845)
  - Added LE support
  - Fixed couple of issues in build tools
  - Removed outdated debian build code
- removed patches:
  * lsvpd.grant_permission_to_link_with_librtas_library.patch
* Fri May  2 2014 jloeser@suse.com
- license amendment needs to be added to lsvpd (BNC#875781)
- added patches:
  * lsvpd.grant_permission_to_link_with_librtas_library.patch
* Mon Mar 17 2014 jloeser@suse.com
- version update to 1.7.4 (BNC#868688)
  - see changelog for changes
  - fix version number typo in changelog (in tarball)
  - added new patch: lsvpd.no-return-in-nonvoid-function.patch
    final 'else' part is missing, 'return 0;' should do the trick
* Thu Jan 16 2014 jloeser@suse.com
- update to version 1.7.3 (FATE#315458)
  - vpdupdate: Find the PCI/USB ids files at runtime
  - lscfg: allow -z, -d with -p
  - lsvpd.spec.in: run vpdupdate in background post rpm install
  - Remove unused variables in invscout, lscfg.
  - lscfg -vp: Skip empty record
  - lscfg: Display Microcode Image level (MI)
  - "lscfg -vpl sysplaner0" ouptut alignment fix
  - Display "Machine Model" information in lscfg output
  - Support for device listing using location code with lsvpd -l
  - Added man page for invscout
  - Man pages updated to remove license info.
  - Man pages updated to use correct vpd DB filename, document
  - l feature.
* Tue Dec 10 2013 dvaleev@suse.com
- add ppc64le
* Wed Dec  5 2012 dvaleev@suse.com
- update to 1.7.0:
  Added new tool - invscout (written by Aravinda Prasad)
  Better support for SCSI enclosures and SCSI devices
  Dynamic system firmware level from RTAS for lsmcode.
- fix gcc4.7 build (gcc47-fix.patch)
- fix no return in non void function (invscout)
  (invscout-no-return-fix.patch)
- Don't run autoreconf
- Remove automake, autoconf, libtool from BuildRequires
* Fri Jun  1 2012 jloeser@suse.com
- update to version 1.6.12
  No detailed changelog provided by upstream
* Thu Jan 26 2012 dvaleev@suse.com
- add autoconf, libtool and automake to buildrequires
* Wed Nov  2 2011 dvaleev@suse.com
- update to 1.6.11
- Fixed the way we find devices in /sys.  Many
  non-device directories were being identified as devices.
- Minor update: Changed default lsvpd output to use
  "Size" instead of "SZ" for DIMM size output.  This was done
  to conform to the way AIX/lsvpd outputs this VPD
- Minor update: Fixed location code discovery for
  storage devices. Previously, a loc-code was generated simply
  using the device node within the /proc/device-tree/devices
  file-system.  This behavior caused usysident to get a
  listing of invalid loc-codes.  This patch is a short-term
  fix, causing each port device to use the adapters loc-code.
  Longer-term fix will be to take this loc-code and add on
  port-specific modifiers queried from the device
- Fixed the way we find devices in /sys.  Many
  non-device directories were being identified as devices.
- Switch to ExclusiveArch
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Thu Sep  3 2009 aj@suse.de
- Fix build with current sg_utils.
* Tue Jun  9 2009 coolo@novell.com
- fix build
* Mon Mar  2 2009 crrodriguez@suse.de
- this package no longer uses db43, remove it from BuildRequires
* Fri Jan  9 2009 olh@suse.de
- add BuildRequires: librtas (bnc#464047 - LTC50935)
* Mon Dec  8 2008 olh@suse.de
- remove pciutils and usbutils from buildrequires
  they were used to get the location of pci/usb.ids
  specify the correct location as compiletime option,
  instead of incorrectly guessing the location
* Wed Nov 26 2008 sassmann@suse.de
- package libvpd_cxx2 has been renamed to libvpd2
  (adjusting BuildRequires)
* Wed Jun 25 2008 olh@suse.de
- update lsvpd (version 1.6.5)
  builds against libvpd_cxx2
* Mon May 26 2008 ro@suse.de
- buildreq sg3_utils-devel instead of scsi
* Mon Nov 19 2007 sassmann@suse.de
- update lsvpd (version 1.4.0 - fate #302692)
- Removing udev rules from install as they are causing problems.  Hotplug will be diabled until we find a smater way of handling it.
- Updating License
- Adjusting the way vpdupdater is inserted into run control
- Removing #! from the beginning of the file.
- Fixes requested by Fedora Community
* Tue Nov 13 2007 sassmann@suse.de
- update lsvpd (version 1.3.5 - fate #302692)
- added lsvpd.db43-Makefile-fix.patch
  fixes Makefile errors concerning Berkeley DB
- merged lsvpd.db_cxx.patch
  in lsvpd.db43-Makefile-fix.patch
- rebased lsvpd.runlevel-script.patch to version 1.3.5
- rebased lsvpd.cxx-includes.patch to version 1.3.5
- updated %%post to remove and rebuild db on install
* Fri Nov  2 2007 olh@suse.de
- run vpdupdate during update to reinitialize db (308679)
* Tue Oct  9 2007 olh@suse.de
- fix c++ includes
* Wed Sep 26 2007 olh@suse.de
- update to 1.3.3
  Fixed locking issue with Berkeley DB. This should take care of
  random crashes during the first run at boot. (308679)
* Sat Aug  4 2007 olh@suse.de
- update to 1.3.1
  db4.3 changes partly merged
* Mon Jul  2 2007 olh@suse.de
- update to 1.3.0
  add udev support
* Mon May 21 2007 dmueller@suse.de
- build against db 4.3
* Thu Mar 29 2007 olh@suse.de
- add zlib-devel to buildrequires
* Wed Feb 14 2007 olh@suse.de
- fix libsgutils linking for lib64, use shared libsgutils
* Tue Feb 13 2007 olh@suse.de
- update to 1.0.3
  complete rewrite in C++
  binaries moved to /usr/sbin
* Mon Dec 11 2006 olh@suse.de
- fix incorrect string comparsion in device_scsi.c (#227459)
* Sun Nov 19 2006 olh@suse.de
- install scripts correctly, fix incorrect quoting in Makefile (#222542)
* Sun Oct  8 2006 olh@suse.de
- linux/ethtool.h needs linux/types.h
* Fri Sep 15 2006 olh@suse.de
- update to lsvpd-0.16.0
  improved sysfs support
* Fri Jul 28 2006 olh@suse.de
- boot.localfs is optional (#181972)
* Thu Jul 20 2006 olh@suse.de
- update to lsvpd-0.15.1
  On IBM POWER machines running Linux 2.6, USB device
  location codes have a better chance of being correct.
  lsvpd no longer puts "/dev/" at the beginning of device
  names in the AX field.
  lscfg now knows about the PR and FG fields.
  For SCSI device VPD, if SCSI inquiry-based VPD retrieval
  fails then VPD is manufactured using sysfs (if available).
  This works around a problem with some tape drives (or
  their drivers) that don't allow inquiries when they are in
  use.
  SCSI adapter channels with number 0xff are once again
  listed.
  IBM virtual SCSI adapters now have a more sensible
  description - the word "SCSI" should now only appear once.
  Added support for token ring adapters and communications
  controllers.  The latter is implemented using new generic
  PCI adapter support, which allows addition of new PCI
  adapter types via a single line of code.  The list of
  (partial) PCI classes that use this feature could later be
  moved to a "configuration" file.
  Sort order of VPD for SCSI-like devices has changed
  subtly.  YL is now at the end of the VPD, as for adapters
  and other devices.
* Sun Apr 23 2006 olh@suse.de
- add /etc/cron.daily/lsvpd to remove old device-tree copies
  they fill up the harddisk if the device-tree content changes,
  compared to the previous boot
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec  8 2005 olh@suse.de
- update to lsvpd-0.14.1
* Mon Nov  7 2005 olh@suse.de
- use LSB exit codes in runlevel script (112623)
* Wed Oct 26 2005 olh@suse.de
- update to lsvpd-0.13.2
* Fri Aug 26 2005 olh@suse.de
- build with -fno-unit-at-a-time to keep linker sections
* Fri Aug  5 2005 olh@suse.de
- update to lsvpd-0.13.0
* Fri Jul  1 2005 olh@suse.de
- update to lsvpd-0.12.7
  use RPM_OPT_FLAGS
* Mon Aug 16 2004 garloff@suse.de
- update to lsvpd-0.12.0
* Sun May  9 2004 olh@suse.de
- insserv per default only on ppc (#39117)
* Mon Mar  1 2004 olh@suse.de
- update to lsvpd-0.11.5
* Mon Feb 23 2004 olh@suse.de
- update to lsvpd-0.11.4
* Sun Aug 10 2003 olh@suse.de
- update to this weeks gnome includes
* Wed May 21 2003 olh@suse.de
- update to version lsvpd-0.8.4
  bugfis release, support for ibmsis, sym53c8xx fixes
* Wed Apr  9 2003 jplack@suse.de
- update to version lsvpd-0.8.1
* Wed Mar 19 2003 olh@suse.de
- update to version lsvpd-0.6.5
* Tue Mar 18 2003 olh@suse.de
- add a workaround for missing ibm,read-pci-config nodes
* Thu Mar 13 2003 olh@suse.de
- update to version lsvpd-0.6.2
* Wed Mar 12 2003 olh@suse.de
- update to version lsvpd-0.6.1
* Tue Mar 11 2003 olh@suse.de
- initial version lsvpd-0.5.5, tweak init scripts
